SemiLogData class

data for block print

Constructors

SemiLogData(SemiLogLevel level, String msg)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
level SemiLogLevel
level use for block print
final
msg String
massage use for block print
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited