SemiLogLevel enum
Log level for styling print
- Inheritance
- Available extensions
Values
- print → const SemiLogLevel
- header → const SemiLogLevel
- separator → const SemiLogLevel
- warn → const SemiLogLevel
- error → const SemiLogLevel
- info → const SemiLogLevel
- debug → const SemiLogLevel
- success → const SemiLogLevel
- fail → const SemiLogLevel
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
log(
String message) → void -
Available on SemiLogLevel, provided by the SemiLogLevelX extension
another log print -
msg(
String message) → SemiLogData -
Available on SemiLogLevel, provided by the SemiLogLevelX extension
use for log a block -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toContent(
String message) → SemiLogContent -
Available on SemiLogLevel, provided by the SemiLogLevelX extension
convert to SemiLogContent -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SemiLogLevel> - A constant List of the values in this enum, in order of their declaration.