SemiLogStyle class

The style for each level

Implementers

Constructors

SemiLogStyle([Set<ANSIStyles> styles = const {}])
const
SemiLogStyle.generate({ANSIStyles? color, ANSIStyles? bg, bool bold = false, bool underline = false, bool blink = false, bool reverse = false, bool concealed = false, bool italic = false, bool dark = false})
another contructor
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles Set<ANSIStyles>
get text style
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toContent(String message) SemiLogContent
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited