SemiLogStyleData class

Your styles of logger

Constructors

SemiLogStyleData({SemiLogStyle header = const SemiLogStyle({ANSIStyles.lightGray}), SemiLogStyle separator = const SemiLogStyle({ANSIStyles.lightGray}), SemiLogStyle debug = const SemiLogStyle(), SemiLogStyle warn = const SemiLogStyle({ANSIStyles.yellow}), SemiLogStyle error = const SemiLogStyle({ANSIStyles.red}), SemiLogStyle info = const SemiLogStyle(), SemiLogStyle fail = const SemiLogStyle({ANSIStyles.lightRed}), SemiLogStyle success = const SemiLogStyle({ANSIStyles.green})})
const

Properties

debug SemiLogStyle
final
error SemiLogStyle
final
fail SemiLogStyle
final
hashCode int
The hash code for this object.
no setterinherited
final
info SemiLogStyle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separator SemiLogStyle
final
success SemiLogStyle
final
warn SemiLogStyle
final

Methods

getStyle(SemiLogLevel level) Set<ANSIStyles>
return your style with level
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited