SemiLogContent class
- Inheritance
-
- Object
- SemiLogStyle
- SemiLogContent
Constructors
-
SemiLogContent(String msg, [Set<
ANSIStyles> styles = const {}]) -
const
- SemiLogContent.generate(String msg, {ANSIStyles? color, ANSIStyles? bg, bool bold = false, bool underline = false, bool blink = false, bool reverse = false, bool concealed = false, bool italic = false, bool dark = false})
-
another contructor
factory
-
SemiLogContent.styles(String msg, {Set<
ANSIStyles> styles = const {}}) -
another contructor
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- msg → String
-
The message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
styles
→ Set<
ANSIStyles> -
get text style
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toContent(
String message) → SemiLogContent -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited